package app.insti.activity;

import androidx.annotation.NonNull;
import androidx.appcompat.app.AppCompatActivity;
import androidx.drawerlayout.widget.DrawerLayout;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;

import android.content.Context;
import android.content.Intent;
import android.os.Bundle;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.MenuItem;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Toast;
import androidx.appcompat.widget.Toolbar;

import com.google.android.material.navigation.NavigationView;
import com.google.firebase.database.DataSnapshot;
import com.google.firebase.database.DatabaseError;
import com.google.firebase.database.DatabaseReference;
import com.google.firebase.database.FirebaseDatabase;
import com.google.firebase.database.ValueEventListener;
import com.google.firebase.storage.StorageReference;

import java.util.ArrayList;
import java.util.List;

import app.insti.R;
import app.insti.Utils;
import app.insti.adapter.ActivitiesAdapter;
import app.insti.adapter.RecyclerViewAdapter;
import app.insti.api.model.BroadActivity;

public class BroadActivities extends AppCompatActivity implements ActivitiesAdapter.OnBroadActivityListener{

    private static final String TAG = "BroadActivities";

    private RecyclerView recyclerView;
    private StorageReference storageReference;
    private DatabaseReference databaseReference;
    private List<BroadActivity> broadActivityList = new ArrayList<>();
    private ActivitiesAdapter activitiesAdapter;
    private ActivitiesAdapter.OnBroadActivityListener broadActivityListener;



    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_broad);
        recyclerView = findViewById(R.id.broadActivityRecyclerView);

        initRecyclerView();
        insertBroadActivities();

//        Toolbar toolbar = findViewById(R.id.toolbar1);
//        toolbar.setTitle("Activities");
//        Utils.setSelectedMenuItem(this, R.id.nav_broad_activities);

    }

    private void initRecyclerView() {
        LinearLayoutManager linearLayoutManager = new LinearLayoutManager(this);
        recyclerView.setLayoutManager(linearLayoutManager);
        broadActivityListener = this;
        activitiesAdapter = new ActivitiesAdapter(broadActivityList,this);
        recyclerView.setAdapter(activitiesAdapter);

        setSupportActionBar(findViewById(R.id.toolbar));
        setTitle("Activities");
    }

    private void insertBroadActivities(){
//        broadActivityList = new ArrayList<>();
//        for(int i=0;i<3;i++){
//            BroadActivity broadActivity = new BroadActivity();
//            broadActivity.setBroadActivityName("Activity"+i);
//            broadActivity.setBroadActivityImageURL("https://firebasestorage.googleapis.com/v0/b/insticonnect-45378.appspot.com/o/broadActivityImages%2Fadventures.jpg?alt=media&token=3077eaf3-abe5-4b72-9205-1702e8887bb6");
//            broadActivityList.add(broadActivity);
//        }
        databaseReference = FirebaseDatabase.getInstance().getReference("activities");
        databaseReference.addValueEventListener(new ValueEventListener() {
            @Override
            public void onDataChange(DataSnapshot dataSnapshot) {
                // This method is called once with the initial value and again
                // whenever data at this location is updated.
                for(DataSnapshot activitySnapshot : dataSnapshot.getChildren()){
                    BroadActivity broadActivity = activitySnapshot.getValue(BroadActivity.class);
                    broadActivityList.add(broadActivity);
                }
                ActivitiesAdapter broadActivityAdapter = new ActivitiesAdapter(broadActivityList,broadActivityListener);
                recyclerView.setAdapter(broadActivityAdapter);
            }

            @Override
            public void onCancelled(DatabaseError error) {
                // Failed to read value
                Log.w(TAG, "Failed to read value.", error.toException());
            }
        });
//        activitiesAdapter.notifyDataSetChanged();

    }

    @Override
    protected void onStart() {
        super.onStart();
    }

    @Override
    public void onBroadActivityClick(int position) {
        Intent intent = new Intent(this,SubActivities.class);
        intent.putExtra("broadActivityNameClicked",broadActivityList.get(position).getBroadActivityID());
        startActivity(intent);
    }
}
