package app.insti.activity;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.annotation.RequiresApi;
import androidx.appcompat.app.AppCompatActivity;

import android.content.ContentResolver;
import android.content.Intent;
import android.graphics.Bitmap;
import android.net.Uri;
import android.os.Build;
import android.os.Bundle;
import android.provider.MediaStore;
import android.util.Log;
import android.view.View;
import android.webkit.MimeTypeMap;
import android.widget.Button;
import android.widget.EditText;
import android.widget.ImageView;
import android.widget.ProgressBar;
import android.widget.Toast;

import com.google.android.gms.tasks.OnCompleteListener;
import com.google.android.gms.tasks.OnFailureListener;
import com.google.android.gms.tasks.OnSuccessListener;
import com.google.android.gms.tasks.Task;
import com.google.firebase.auth.AuthResult;
import com.google.firebase.auth.FirebaseAuth;
import com.google.firebase.auth.FirebaseUser;
import com.google.firebase.database.DatabaseReference;
import com.google.firebase.database.FirebaseDatabase;
import com.google.firebase.storage.FirebaseStorage;
import com.google.firebase.storage.OnProgressListener;
import com.google.firebase.storage.StorageReference;
import com.google.firebase.storage.UploadTask;

import java.io.FileNotFoundException;
import java.io.IOException;
import java.util.UUID;

import app.insti.R;
import app.insti.api.model.MyEvent;

public class CreateEventActivity extends AppCompatActivity {

    private EditText eventName;
    private EditText eventVenue;
    private EditText eventDescription;
    private EditText eventTime;
    private EditText eventDate;
    private ImageView eventImage;
    private Button eventSubmit;
//    private Button uploadImage;
    private Button chooseImage;
    private ImageView imageView;
    private final int PICK_IMAGE_REQUEST = 7;

    private Uri filePath;

    private StorageReference storageReference;
    private DatabaseReference databaseReference;
    private FirebaseStorage firebaseStorage;
    private String event_image_url;
    private static final String TAG = "Create Activity";
    private FirebaseAuth mAuth;
    private String eventIdCreated;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_create_event);
        eventName = findViewById(R.id.event_name);
        eventVenue = findViewById(R.id.event_venue);
        eventTime = findViewById(R.id.event_time);
        eventDate = findViewById(R.id.event_date);
        eventDescription = findViewById(R.id.event_description);
        eventSubmit = findViewById(R.id.event_submit);
        chooseImage = findViewById(R.id.img_choose);
//        uploadImage = findViewById(R.id.img_upload);
        imageView = findViewById(R.id.show_image);
        databaseReference = FirebaseDatabase.getInstance().getReference("my_events");
        storageReference = FirebaseStorage.getInstance().getReference();
        mAuth = FirebaseAuth.getInstance();

        eventSubmit.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                String name = eventName.getText().toString();
                String venue = eventVenue.getText().toString();
                String date = eventDate.getText().toString();
                String time = eventTime.getText().toString();
                String description = eventDescription.getText().toString();
                int going = 0;
                int interested = 0;
                String id = "event"+Math.random();
//                String url = "https://firebasestorage.googleapis.com/v0/b/insticonnect-45378.appspot.com/o/eventImages%2Fsameer_hill.jpg?alt=media&token=fe0d8eaa-2a36-49a2-9456-1c67c0c3b283";
                String parent = "hanging_out";

//                createNewEvent(name,venue,date,time,description,going,interested,id,parent,url);
                createNewEvent(name,venue,date,time,description,going,interested,id,parent);
                uploadImage(name);
            }
        });

        chooseImage.setOnClickListener(new View.OnClickListener() {
            @RequiresApi(api = Build.VERSION_CODES.LOLLIPOP_MR1)
            @Override
            public void onClick(View v) {
                chooseImage();
            }
        });

    }

    @Override
    protected void onStart() {
        super.onStart();
        FirebaseUser currentUser = mAuth.getCurrentUser();
        signInAnonymously();
    }


    private void uploadImage(String name) {
        if (filePath != null) {
            StorageReference ref = storageReference.child("eventImages/"+name);
            ref.putFile(filePath).addOnSuccessListener(new OnSuccessListener<UploadTask.TaskSnapshot>() {
                @Override
                public void onSuccess(UploadTask.TaskSnapshot taskSnapshot) {
                    System.out.println("*****************************************************");
                    System.out.println("*****************************************************");
                    System.out.println(taskSnapshot);
                    System.out.println("****************************************************");
                    System.out.println("*****************************************************");
                }
            })
            .addOnFailureListener(new OnFailureListener() {
                @Override
                public void onFailure(@NonNull Exception e) {
                    Toast.makeText(getApplicationContext(),"Failed Upload", Toast.LENGTH_SHORT).show();
                }
            });
        }
    }

    private void signInAnonymously() {
        // [START signin_anonymously]
        mAuth.signInAnonymously()
                .addOnCompleteListener(this, new OnCompleteListener<AuthResult>() {
                    @Override
                    public void onComplete(@NonNull Task<AuthResult> task) {
                        if (task.isSuccessful()) {
                            // Sign in success, update UI with the signed-in user's information
                            Log.d(TAG, "signInAnonymously:success");
                            FirebaseUser user = mAuth.getCurrentUser();
                        } else {
                            // If sign in fails, display a message to the user.
                            Log.w(TAG, "signInAnonymously:failure", task.getException());
                        }
                    }
                });
        // [END signin_anonymously]
    }


    @RequiresApi(api = Build.VERSION_CODES.LOLLIPOP_MR1)
    private void chooseImage() {
        Intent intent = new Intent();
        intent.setType("image/*");
        intent.setAction(Intent.ACTION_GET_CONTENT);
        startActivityForResult(Intent.createChooser(intent,"Select Picture"),PICK_IMAGE_REQUEST);
    }

    private void createNewEvent(String name, String venue, String date, String time, String description, int going, int interested, String id, String parent) {
        MyEvent myEvent = new MyEvent(name,venue,date,time,description,going,interested,parent,id);
        String eventId = databaseReference.push().getKey();
        databaseReference.child(eventId).setValue(myEvent);
        eventIdCreated = eventId;
    }

    @Override
    protected void onActivityResult(int requestCode, int resultCode, @Nullable Intent data) {
        super.onActivityResult(requestCode, resultCode, data);
        if(requestCode == PICK_IMAGE_REQUEST && resultCode == RESULT_OK && data !=null && data.getData() != null){
            filePath = data.getData();
            try{
                Bitmap bitmap = MediaStore.Images.Media.getBitmap(getContentResolver(),filePath);
                imageView.setVisibility(View.VISIBLE);
                imageView.setImageBitmap(bitmap);

            } catch (FileNotFoundException e) {
                e.printStackTrace();
            } catch (IOException e) {
                e.printStackTrace();
            }
        }
    }
}
