package app.insti.activity;

import androidx.appcompat.app.AppCompatActivity;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;

import android.content.Intent;
import android.os.Bundle;
import android.util.Log;
import android.widget.Toast;

import com.google.firebase.database.DataSnapshot;
import com.google.firebase.database.DatabaseError;
import com.google.firebase.database.DatabaseReference;
import com.google.firebase.database.FirebaseDatabase;
import com.google.firebase.database.ValueEventListener;
import com.google.firebase.storage.StorageReference;

import java.util.ArrayList;
import java.util.List;

import app.insti.R;
import app.insti.adapter.ActivitiesAdapter;
import app.insti.adapter.SubActivitiesAdapter;
import app.insti.api.model.BroadActivity;
import app.insti.api.model.SubActivity;

public class SubActivities extends AppCompatActivity implements SubActivitiesAdapter.OnSubActivityListener {

    private static final String TAG = "SubActivities";
    private RecyclerView recyclerView;
    private StorageReference storageReference;
    private DatabaseReference databaseReference;
    private List<SubActivity> subActivityList = new ArrayList<>();
    private SubActivitiesAdapter subActivitiesAdapter;
    private SubActivitiesAdapter.OnSubActivityListener subActivityListener;
    private String broadActivityNameClicked;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_sub);
//        Toast.makeText(getApplicationContext(),"subactivity",Toast.LENGTH_SHORT).show();
//        Toast.makeText(getApplicationContext(),getIntent().getStringExtra("message"),Toast.LENGTH_SHORT).show();
        recyclerView = findViewById(R.id.subActivityRecyclerView);
        broadActivityNameClicked = getIntent().getStringExtra("broadActivityNameClicked");
        initRecyclerView();
        insertSubActivities();
    }

    private void insertSubActivities() {
        databaseReference = FirebaseDatabase.getInstance().getReference("sub_activities");
        databaseReference.addValueEventListener(new ValueEventListener() {
            @Override
            public void onDataChange(DataSnapshot dataSnapshot) {
                // This method is called once with the initial value and again
                // whenever data at this location is updated.
                for(DataSnapshot activitySnapshot : dataSnapshot.getChildren()){
                   SubActivity subActivity = activitySnapshot.getValue(SubActivity.class);
                   String subActivityParent = subActivity.getSubActivityParent();
                   if(subActivityParent.equals(broadActivityNameClicked)) {
                       subActivityList.add(subActivity);
                   }
                }
                SubActivitiesAdapter subActivityAdapter = new SubActivitiesAdapter(subActivityList,subActivityListener);
                recyclerView.setAdapter(subActivityAdapter);
            }

            @Override
            public void onCancelled(DatabaseError error) {
                // Failed to read value
                Log.w(TAG, "Failed to read value.", error.toException());
            }
        });
    }

    private void initRecyclerView() {
        LinearLayoutManager linearLayoutManager = new LinearLayoutManager(this);
        recyclerView.setLayoutManager(linearLayoutManager);
        subActivityListener = this;
        subActivitiesAdapter = new SubActivitiesAdapter(subActivityList,subActivityListener);
        recyclerView.setAdapter(subActivitiesAdapter);

        setSupportActionBar(findViewById(R.id.toolbar));
        setTitle("Sub Activities");
    }

    @Override
    public void onSubActivityClick(int position) {
        Intent intent = new Intent(this,EventActivity.class);
        intent.putExtra("subActivityNameClicked",subActivityList.get(position).getSubActivityID());
        startActivity(intent);
    }
}
