package app.insti.adapter;

import android.content.Context;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.TextView;
import android.widget.Toast;

import androidx.annotation.NonNull;
import androidx.recyclerview.widget.RecyclerView;

import com.squareup.picasso.Picasso;

import java.util.ArrayList;
import java.util.List;

import app.insti.R;
import app.insti.api.model.MyEvent;
import app.insti.api.model.SubActivity;

public class MyEventAdapter extends RecyclerView.Adapter<MyEventAdapter.MyEventViewHolder> {

    private List<MyEvent> myEventList = new ArrayList<>();
    private OnMyEventListener onMyEventListener;

    public MyEventAdapter(List<MyEvent> myEventList,OnMyEventListener onMyEventListener) {
        this.myEventList = myEventList;
        this.onMyEventListener = onMyEventListener;
    }

    @NonNull
    @Override
    public MyEventViewHolder onCreateViewHolder(@NonNull ViewGroup parent, int viewType) {
        LayoutInflater inflater = LayoutInflater.from(parent.getContext());
        View view = inflater.inflate(R.layout.resource_layout_my_events,parent,false);
        return new MyEventViewHolder(view,onMyEventListener);
    }

    @Override
    public void onBindViewHolder(@NonNull MyEventViewHolder holder, int position) {
        MyEvent myEvent = myEventList.get(position);
        holder.txtViewMyEventName.setText(myEvent.getMyEventName());
        holder.txtViewMyEventShortDescription.setText(myEvent.getMyEventDescription());
        Picasso.get().load(myEvent.getAvatarUrl()).fit().centerCrop().into(holder.imgViewMyEvent);

    }

    @Override
    public int getItemCount() {
        return myEventList.size();
    }

    public class MyEventViewHolder extends RecyclerView.ViewHolder implements View.OnClickListener {
        ImageView imgViewMyEvent;
        TextView txtViewMyEventName;
        TextView txtViewMyEventShortDescription;
        LinearLayout linearLayoutMyEvent;
        OnMyEventListener onMyEventListener;

        public MyEventViewHolder(@NonNull View itemView,OnMyEventListener onMyEventListener) {
            super(itemView);
            imgViewMyEvent = itemView.findViewById(R.id.imgViewMyEvent);
            txtViewMyEventName = itemView.findViewById(R.id.txtViewMyEventName);
            txtViewMyEventShortDescription = itemView.findViewById(R.id.txtViewMyEventShortDescription);
            linearLayoutMyEvent = itemView.findViewById(R.id.linearLayoutMyEvent);
            this.onMyEventListener = onMyEventListener;
            itemView.setOnClickListener(this);

        }

        @Override
        public void onClick(View v) {
            onMyEventListener.onMyEventClick(getAdapterPosition());
        }
    }

    public interface OnMyEventListener{
        void onMyEventClick(int position);
    }

}
